<?php
/**
 * Controller file for justknit extra
 *
 * Copyright 2023 by Iris Hammer iris@justknit.de
 * Created on 03-20-2023
 *
 * justknit is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * justknit is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * justknit; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * @package justknit
 * @subpackage controllers
 */
/* @var $modx modX */

// Vorlage: core/src/Revolution/modManagerController.php

//namespace JustKnit\Controllers;

use MODX\Revolution\modManagerController;

class JustKnitHomeManagerController extends modManagerController {

    /**
     * Do permission checking in this method. Returning false will present a "permission denied" message.
     *
     * @abstract
     * @return bool
     */
    public function checkPermissions() {
        return true;
    }

    /**
     * Process the controller, returning an array of placeholders to set.
     *
     * @abstract
     *
     * @param array $scriptProperties A array of REQUEST parameters.
     *
     * @return mixed Either an error or output string, or an array of placeholders to set.
     */
    public function process(array $scriptProperties = []) {
//$this->modx->log( modX::LOG_LEVEL_ERROR,'[JustKnit] process()-mgr contextKey'.$this->modx->context->get('key').' $_SESSION: '.print_r($_SESSION, 1));
        return '<div id="justknit-panel-home-div"></div>';
    }
    /**
     * Return a string to set as the controller's page title.
     *
     * @abstract
     * @return string
     */
    public function getPageTitle() {
        return $this->modx->lexicon('justknit');
//        return 'JustKnit';
    }

    /**
     * Register any custom CSS or JS in this method.
     *
     * @abstract
     * @return void
     */
    public function loadCustomCssJs() {
        $jsUrl = $this->modx->getOption('assets_url', null, MODX_ASSETS_URL) . 'components/justknit/js/mgr/';
        /* load page */
        $this->addJavascript($jsUrl . 'justknit.js');
        /* load Sections */
        $this->addJavascript($jsUrl . 'sections/home.panel.js');
        /* load widgets */
        $this->addJavascript($jsUrl . 'widgets/order.panel.js');
        $this->addJavascript($jsUrl . 'widgets/product.panel.js');
        $this->addJavascript($jsUrl . 'widgets/client.panel.js');
        $this->addJavascript($jsUrl . 'widgets/calc.panel.js');

//        $this->addJavascript($jsUrl . 'sections/home.panel.js');
//        $this->addJavascript($jsUrl . 'subscribers.grid.js');
        //$this->modx->log(modX::LOG_LEVEL_ERROR,'$js: '.$jsUrl . 'justknit.js');
    }

    /**
     * Return the relative path to the template file to load
     *
     * @abstract
     * @return string
     */
    public function getTemplateFile() {
//        return $this->justknit->config['templatesPath'].'home.tpl';
        return '';
    }

    /**
     * Specify an array of language topics to load for this controller
     *
     * @return array
     */
    public function getLanguageTopics() {
//        return array('justknit:default');
        return array('justknit:mgr');
    }
}
    // /**
    //  * The pagetitle to put in the <title> attribute.
    //  *
    //  * @return null|string
    //  */
    // public function getPageTitle() {
    //     return $this->modx->lexicon('justknit');
    // }
    //
    // /**
    //  * Register all the needed javascript files.
    //  */
    //
    //
    // public function loadCustomCssJs() {
    //     $this->addJavascript($this->justknit->config['jsUrl'] . 'widgets/chunk.grid.js');
    //     $this->addJavascript($this->justknit->config['jsUrl'] . 'widgets/snippet.grid.js');
    //     $this->addJavascript($this->justknit->config['jsUrl'] . 'widgets/home.panel.js');
    //     $this->addLastJavascript($this->justknit->config['jsUrl'] . 'sections/home.js');
    //
    //     $this->addCss($this->justknit->config['cssUrl'] . 'mgr.css');
    //
    //
    // }

