<?php

/**
 * This file is part of the JustKnit package.
 *
 * @copyright zahlenhexe (Iris Hammer)
 * @license GNU General Public License v2.0 (and later)
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace JustKnit\Processors\Subscriber;

use MODX\Revolution\Processors\Model\GetListProcessor;
use JustKnit\Model\JustKnitSubscriberMeta;
use MODX\Revolution\modUser;
use MODX\Revolution\modUserProfile;
use MODX\Revolution\modUserGroup;
use xPDO\Om\xPDOObject;
use xPDO\Om\xPDOQuery;
use MODX\Revolution\modX;

class GetList extends GetListProcessor {

    public $classKey = JustKnitSubscriberMeta::class;
//    public $classKey = modUser::class;
    public $defaultSortField = 'id';
    public $defaultSortDirection = 'ASC';
//    public $objectType = 'justknit.subscriber';

//    public $classKey = modUser::class;
//    public $defaultSortField = 'Profile.email';
public function prepareQueryBeforeCount(xPDOQuery $c)
    {
        //$c->leftJoin(modUser::class, 'JustKnitSubscriberMeta', 'modUser.id = JustKnitSubscriberMeta.subscriber_id');
        $c->leftJoin(modUser::class, 'User',  'JustKnitSubscriberMeta.subscriber_id = User.id');
        $c->leftJoin(modUserProfile::class, 'Profile',  'JustKnitSubscriberMeta.subscriber_id = Profile.internalKey');
/*
 * Für die Doofen: 
 * Der Join geht so:
 * leftJoin( Classe, Alias für diese Klasse im Kontext, ON Statement unter Verwendung des Alias)
 * 
 * Join für zwei Tabellen: 
 * SELECT * 
 * FROM `rv_justknit_subscriber_meta` AS `JustKnitSubscriberMeta` 
 * LEFT JOIN `rv_users` `User` ON JustKnitSubscriberMeta.subscriber_id = User.id
 * LEFT JOIN `rv_user_attributes` `Profile`  on JustKnitSubscriberMeta.subscriber_id = Profile.internalKey;
 * 
 */
        $c->select($this->modx->getSelectColumns(
            modUser::class,
            'User',
            '',
            ['username', 'active', 'primary_group']
        ));
        $c->select($this->modx->getSelectColumns(
            modUserProfile::class,
            'Profile',
            '',
            ['internalKey', 'fullname', 'email', 'blocked', 'blockedafter','logincount',  'lastlogin', 'thislogin ','failedlogincount', 'comment']
        ));
        $c->select($this->modx->getSelectColumns(
            JustKnitSubscriberMeta::class,
            'JustKnitSubscriberMeta',
            '',
            ['id', 'subscriber_id' , 'first_name' , 'last_name' , 'nick_name' , 'sid' , 'active_order' , 'active_product' , 'subscribedon' , 'activatedon' , 'subscriber_blockedafter' , 'subscriber_blocked' , 'subscriber_deletedafter' , 'subscriber_deleted']
        ));       
        
        
        $query = $this->getProperty('query');
        if (!empty($query)) {
            $c->where(
                [
                    'first_name:LIKE' => '%' . $query . '%',
                    'OR:last_name:LIKE' => '%' . $query . '%',
                    'OR:email' => '%' . $query . '%'

                ]
            );
        }
        $groupfilter = $this->getProperty('groupfilter', '');
$this->modx->log(modX::LOG_LEVEL_ERROR,'$groupfilter: ' . $groupfilter);
        if (!empty($groupfilter)) {
            //$c->leftJoin( 'JustKnitSubscriberMeta', modUser::class, 'JustKnitSubscriberMeta.subscriber_id = modUser.id');
            if ($groupfilter == 'nogroup') {
                $c->where(['User.primary_group' => null]);
            } else {
                $c->where(['User.primary_group' => $groupfilter]);
            }

//            $c->leftJoin(modUserGroup::class, 'JustKnitSubscriberMeta', 'modUserGroup.id = JustKnitSubscriberMeta.member_id');
//SELECT * FROM `rv_users` left Join `rv_justknit_subscriber_meta` on `rv_users`.`id` = `rv_justknit_subscriber_meta`.`subscriber_id` where `rv_users`.`primary_group` = 2
        }
        $blockedafterfilter = $this->getProperty('blockedafterfilter', '');
        $this->modx->log(modX::LOG_LEVEL_ERROR,'$blockedafterfilter: '. $blockedafterfilter);
        if ($blockedafterfilter) {
            $c->where(['Profile.blockedafter:>=' => time(), 'OR:Profile.blockedafter:=' => 0 ]);
            //`blockedafter`>=1679993943 or `blockedafter`=0
        }
        $thisloginfilter = $this->getProperty('thisloginfilter', '');
        $interval = $this->modx->getOption('session_cookie_lifetime');
        $time = time();
        $startTime = $time - $interval;
        if ($thisloginfilter) {
            $c->where(['Profile.thislogin:>=' => $startTime,
        'AND:Profile.thislogin:<=' => $time]);
        }

/*
    $time = time();
    $startTime = $time - $interval;
    $where = $modx->getOption('where', $scriptProperties, '');
    $where = $modx->fromJSON($where);
    $where[] = array(
        'UsersOnline.lastvisit:>=' => $startTime,
        'UsersOnline.lastvisit:<=' => $time,
    );
*/

$c->prepare();
$this->modx->log(modX::LOG_LEVEL_ERROR,'$c: '. $c->toSQL());

        return $c;
       
    }
public function prepareQueryAfterCount(xPDOQuery $c)
    {
        $c->select($this->modx->getSelectColumns(
            modUser::class,
            'User',
            '',
            ['username', 'active', 'primary_group']
        ));
        $c->select($this->modx->getSelectColumns(
            modUserProfile::class,
            'Profile',
            '',
            ['email', 'comment']
        ));
        $c->select($this->modx->getSelectColumns(
            JustKnitSubscriberMeta::class,
            'JustKnitSubscriberMeta',
            '',
            ['id', 'subscriber_id' , 'first_name' , 'last_name' , 'nick_name' , 'sid' , 'active_order' , 'active_product' , 'subscribedon' , 'activatedon' , 'subscriber_blockedafter' , 'subscriber_blocked' , 'subscriber_deletedafter' , 'subscriber_deleted']
        ));
        
        return $c;
    }
        
/*
 * Hier müssen zusätzlich die Felder aus anderen Tabellen angezeigt werden. 
 * table: user_attributes:
 *      logincount
 *      lastlogin
 *      comment: Passwort speichern??
 *
 *
 *
 *
 *
 */
    
    
}
